@@ -1,5 +1,4 @@
 
 from ._mcubes import marching_cubes, marching_cubes_func
 from .exporter import export_mesh, export_obj, export_off
-from .smoothing import *
-# from .numpy_smoothing import *
+from .smoothing import smooth, smooth_constrained, smooth_gaussian
